# ROADMAP

* [1. Introduction](#1-Introduction)
* [2. Achieved ](#2-Achieved)
* [3. Future](#3-Future)

## 1. Introduction

This document will serve as a ROADMAP for the project. 

## 2. Achieved

Here are listed the milestone achieved by the project team

- Literature Review

- Environment
    - [Implement Generic 2D Environment](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/arena_examples/2d_arenas_examples.ipynb)
    - [Merging room](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/arena_examples/2d_merging_rooms_examples.ipynb) 
    
- Agent
    - [" Learning place cells, grid cells and invariances with excitatory and inhibitory", Weber et al, 2018](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/agent_examples/weber_2018_example.ipynb)
    - [" A general model of hippocampal and dorsal striatal learning and decision making", Stachenfeld et al, 2018](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/agent_examples/stachenfeld_2018_examples.ipynb)
    - [" The Tolman-Eichenbaum Machine: Unifying Space and Relational Memory through Generalization in the Hippocampal Formation", Whittington et al, 2020](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/agent_examples/whittington_2020_examples.ipynb)
   
- Experiments
  - [" Conjunctive Representation of Position, Direction, and Velocity in Entorhinal Cortex", Sargolini et al, 2006](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/experimental_examples/Sargolini_2006_examples.ipynb)
  - [" Hippocampus-independent phase precession in entorhinal grid cells", Hafting et al, 2008](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/experimental_examples/Hafting_2008_examples.ipynb)
  - [" Integration of grid maps in merged environments", Wernle et al, 2018](https://github.com/ClementineDomine/NeuralPlayground/blob/main/examples/experimental_examples/Wernle_2018_examples.ipynb)

- Simulation manager code
- Comparison board from manager results
- Re-factor pre CCN
- Dataset integration with GIN for remote dataset storage
- Developer tools (pre-commit, and others...)
   
### Congratulation Team!

## 3. Future

- Proper documentation on action spaces
- Set default parameters to reproduce source papers
- Adjust levy flight to be more realistic
- Discrete environments (graph like?)
- Set up a webpage for the project
- Include reward in the environment
- Implement a 3D environment
- Implement a 3D agent

### Let's go Team! 
